@@ -1,7 +1,7 @@
 ;; cider-util.el --- Common utility functions that don't belong anywhere else -*- lexical-binding: t -*-
 
-;; Copyright © 2012-2024 Tim King, Phil Hagelberg, Bozhidar Batsov
-;; Copyright © 2013-2024 Bozhidar Batsov, Artur Malabarba and CIDER contributors
+;; Copyright © 2012-2025 Tim King, Phil Hagelberg, Bozhidar Batsov
+;; Copyright © 2013-2025 Bozhidar Batsov, Artur Malabarba and CIDER contributors
 ;;
 ;; Author: Tim King <kingtim@gmail.com>
 ;;         Phil Hagelberg <technomancy@gmail.com>
@@ -69,6 +69,10 @@ Setting this to nil removes the fontification restriction."
   "Return non-nil if current buffer is managed by a ClojureC major mode."
   (derived-mode-p 'clojurec-mode 'clojure-ts-clojurec-mode))
 
+(defun cider-clojure-ts-mode-p ()
+  "Return non-nil if current buffer is managed by a Clojure[TS] major mode."
+  (derived-mode-p 'clojure-ts-mode))
+
 (defun cider-util--clojure-buffers ()
   "Return a list of all existing `clojure-mode' buffers."
   (seq-filter
@@ -107,6 +111,18 @@ If BUFFER is provided act on that buffer instead."
   (with-current-buffer (or buffer (current-buffer))
     (or (cider-clojurec-major-mode-p))))
 
+(defun cider-keyword-at-point-p (&optional point)
+  "Return non-nil if POINT is in a Clojure keyword.
+
+Take into consideration current major mode."
+  (let ((pos (or point (point))))
+    (if (and (cider-clojure-ts-mode-p)
+             (fboundp 'clojure-ts--keyword-node-p)
+             (fboundp 'treesit-node-parent)
+             (fboundp 'treesit-node-at))
+        (clojure-ts--keyword-node-p (treesit-node-parent (treesit-node-at pos)))
+      (member 'clojure-keyword-face (text-properties-at pos)))))
+
 
 ;;; Thing at point
 
@@ -235,6 +251,22 @@ Can only error if SKIP is non-nil."
         (forward-sexp 2)
         (cider-sexp-at-point))
     (error nil)))
+
+
+;;; Plists
+
+(defun cider-plist-get (plist prop)
+  "Extract PROP from PLIST using `equal'.
+
+An alternative `lax-plist-get' that got deprecated in Emacs 29."
+  (lax-plist-get plist prop))
+
+(defun cider-plist-put (plist prop val)
+  "Change value in PLIST of PROP to VAL, comparing with `equal'.
+
+An alternative to `lax-plist-put' that got deprecated in Emacs 29."
+  (lax-plist-put plist prop val))
+
 
 ;;; Text properties
 
@@ -397,19 +429,11 @@ propertized (defaults to current buffer)."
 (defvar cider-version)
 (defvar cider-codename)
 
-(defun cider--pkg-version ()
-  "Extract CIDER's package version from its package metadata."
-  ;; Use `cond' below to avoid a compiler unused return value warning
-  ;; when `package-get-version' returns nil. See #3181.
-  ;; FIXME: Inline the logic from package-get-version and adapt it
-  (cond ((fboundp 'package-get-version)
-         (package-get-version))))
-
 (defun cider--version ()
   "Retrieve CIDER's version.
 A codename is added to stable versions."
   (if (string-match-p "-snapshot" cider-version)
-      (let ((pkg-version (cider--pkg-version)))
+      (let ((pkg-version (package-get-version)))
         (if pkg-version
             ;; snapshot versions include the MELPA package version
             (format "%s (package: %s)" cider-version pkg-version)
