@@ -14,7 +14,7 @@
 ;; Homepage: https://www.github.com/clojure-emacs/cider
 ;; Keywords: languages, clojure, cider
 ;;
-;; Version: 1.19.0
+;; Version: 1.20.0
 ;; Package-Requires: (
 ;;     (emacs "27")
 ;;     (clojure-mode "5.19")
@@ -103,10 +103,10 @@
 (require 'sesman)
 (require 'package)
 
-(defconst cider-version "1.19.0"
+(defconst cider-version "1.20.0"
   "The current version of CIDER.")
 
-(defconst cider-codename "Skiathos"
+(defconst cider-codename "Lanzarote"
   "Codename used to denote stable releases.")
 
 (defcustom cider-lein-command
@@ -518,7 +518,7 @@ Throws an error if PROJECT-TYPE is unknown."
   "List of dependencies where elements are lists of artifact name and version.")
 (put 'cider-jack-in-dependencies 'risky-local-variable t)
 
-(defcustom cider-injected-nrepl-version "1.3.1"
+(defcustom cider-injected-nrepl-version "1.5.1"
   "The version of nREPL injected on jack-in.
 We inject the newest known version of nREPL just in case
 your version of Leiningen is bundling an older one."
@@ -530,7 +530,7 @@ your version of Leiningen is bundling an older one."
   "List of dependencies where elements are lists of artifact name and version.
 Added to `cider-jack-in-dependencies' when doing `cider-jack-in-cljs'.")
 (put 'cider-jack-in-cljs-dependencies 'risky-local-variable t)
-(cider-add-to-alist 'cider-jack-in-cljs-dependencies "cider/piggieback" "0.5.3")
+(cider-add-to-alist 'cider-jack-in-cljs-dependencies "cider/piggieback" "0.6.1")
 
 (defvar cider-jack-in-dependencies-exclusions nil
   "List of exclusions for jack in dependencies.
@@ -549,7 +549,7 @@ the artifact.")
 
 Used when `cider-jack-in-auto-inject-clojure' is set to `latest'.")
 
-(defconst cider-required-middleware-version "0.57.0"
+(defconst cider-required-middleware-version "0.58.0"
   "The CIDER nREPL version that's known to work properly with CIDER.")
 
 (defcustom cider-injected-middleware-version cider-required-middleware-version
